@@ -20,6 +20,10 @@ module Nanoc
   end
 end
 
+# Load external dependencies
+require 'hamster'
+require 'ref'
+
 # Load general requirements
 require 'digest'
 require 'enumerator'
