@@ -22,8 +22,10 @@ module Nanoc::Int
 end
 
 require_relative 'base/core_ext'
+require_relative 'base/contracts_support'
 
 require_relative 'base/entities'
+require_relative 'base/feature'
 require_relative 'base/repos'
 require_relative 'base/services'
 require_relative 'base/views'
