@@ -17,24 +17,31 @@ module Nanoc::Int
     end
 
     CodeSnippetsModified = Generic.new(
-      'The code snippets have been modified since the last time the site was compiled.')
+      'The code snippets have been modified since the last time the site was compiled.',
+    )
 
     ConfigurationModified = Generic.new(
-      'The site configuration has been modified since the last time the site was compiled.')
+      'The site configuration has been modified since the last time the site was compiled.',
+    )
 
     DependenciesOutdated = Generic.new(
-      'This item uses content or attributes that have changed since the last time the site was compiled.')
+      'This item uses content or attributes that have changed since the last time the site was compiled.',
+    )
 
     NotEnoughData = Generic.new(
-      'Not enough data is present to correctly determine whether the item is outdated.')
+      'Not enough data is present to correctly determine whether the item is outdated.',
+    )
 
     NotWritten = Generic.new(
-      'This item representation has not yet been written to the output directory (but it does have a path).')
+      'This item representation has not yet been written to the output directory (but it does have a path).',
+    )
 
     RulesModified = Generic.new(
-      'The rules file has been modified since the last time the site was compiled.')
+      'The rules file has been modified since the last time the site was compiled.',
+    )
 
     SourceModified = Generic.new(
-      'The source file of this item has been modified since the last time the site was compiled.')
+      'The source file of this item has been modified since the last time the site was compiled.',
+    )
   end
 end
