@@ -44,7 +44,7 @@ module Nanoc::CLI
     # Asserts that the current working directory contains a site and loads the site into memory.
     #
     # @return [void]
-    def load_site
+    def load_site(preprocess: false)
       print 'Loading site… '
       $stdout.flush
 
@@ -52,6 +52,10 @@ module Nanoc::CLI
         raise ::Nanoc::Int::Errors::GenericTrivial, 'The current working directory does not seem to be a Nanoc site.'
       end
 
+      if preprocess
+        site.compiler.action_provider.preprocess(site)
+      end
+
       puts 'done'
     end
 
