@@ -12,7 +12,7 @@ module Nanoc::CLI::Commands
   class Check < ::Nanoc::CLI::CommandRunner
     def run
       validate_options_and_arguments
-      load_site
+      load_site(preprocess: true)
 
       runner = Nanoc::Extra::Checking::Runner.new(site)
 
