@@ -14,6 +14,7 @@ IDENTICAL - The item was deemed outdated and has been recompiled, but the compil
 SKIP - The item was deemed not outdated and was therefore not recompiled
 
 EOS
+flag nil, :profile, 'profile compilation' if Nanoc::Feature.enabled?('PROFILER')
 
 module Nanoc::CLI::Commands
   class Compile < ::Nanoc::CLI::CommandRunner
@@ -49,6 +50,18 @@ module Nanoc::CLI::Commands
       # @return [void]
       def stop
       end
+
+      # @api private
+      def start_safely
+        start
+        @_started = true
+      end
+
+      # @api private
+      def stop_safely
+        stop if @_started
+        @_started = false
+      end
     end
 
     # Generates diffs for every output file written
@@ -63,10 +76,10 @@ module Nanoc::CLI::Commands
         require 'tempfile'
         setup_diffs
         old_contents = {}
-        Nanoc::Int::NotificationCenter.on(:will_write_rep) do |rep, path|
+        Nanoc::Int::NotificationCenter.on(:will_write_rep, self) do |rep, path|
           old_contents[rep] = File.file?(path) ? File.read(path) : nil
         end
-        Nanoc::Int::NotificationCenter.on(:rep_written) do |rep, path, _is_created, _is_modified|
+        Nanoc::Int::NotificationCenter.on(:rep_written, self) do |rep, path, _is_created, _is_modified|
           unless rep.binary?
             new_contents = File.file?(path) ? File.read(path) : nil
             if old_contents[rep] && new_contents
@@ -80,6 +93,10 @@ module Nanoc::CLI::Commands
       # @see Listener#stop
       def stop
         super
+
+        Nanoc::Int::NotificationCenter.remove(:will_write_rep, self)
+        Nanoc::Int::NotificationCenter.remove(:rep_written, self)
+
         teardown_diffs
       end
 
@@ -298,12 +315,6 @@ module Nanoc::CLI::Commands
         Nanoc::Int::NotificationCenter.on(:filtering_ended) do |rep, filter_name|
           puts "*** Ended filtering #{rep.inspect} with #{filter_name}"
         end
-        Nanoc::Int::NotificationCenter.on(:visit_started) do |item|
-          puts "*** Started visiting #{item.inspect}"
-        end
-        Nanoc::Int::NotificationCenter.on(:visit_ended) do |item|
-          puts "*** Ended visiting #{item.inspect}"
-        end
         Nanoc::Int::NotificationCenter.on(:dependency_created) do |src, dst|
           puts "*** Dependency created from #{src.inspect} onto #{dst.inspect}"
         end
@@ -326,15 +337,13 @@ module Nanoc::CLI::Commands
         Nanoc::Int::NotificationCenter.on(:rep_written) do |_rep, path, is_created, is_modified|
           duration = path && @start_times[path] ? Time.now - @start_times[path] : nil
           action =
-            case
-            when is_created  then :create
-            when is_modified then :update
+            if is_created then :create
+            elsif is_modified then :update
             else :identical
             end
           level =
-            case
-            when is_created  then :high
-            when is_modified then :high
+            if is_created then :high
+            elsif is_modified then :high
             else :low
             end
           log(level, action, path, duration)
@@ -358,6 +367,28 @@ module Nanoc::CLI::Commands
       end
     end
 
+    # Records a profile using StackProf
+    class StackProfProfiler < Listener
+      PROFILE_FILE = 'tmp/stackprof_profile'.freeze
+
+      # @see Listener#enable_for?
+      def self.enable_for?(command_runner)
+        command_runner.options.fetch(:profile, false)
+      end
+
+      # @see Listener#start
+      def start
+        require 'stackprof'
+        StackProf.start(mode: :cpu)
+      end
+
+      # @see Listener#stop
+      def stop
+        StackProf.stop
+        StackProf.results(PROFILE_FILE)
+      end
+    end
+
     attr_accessor :listener_classes
 
     def initialize(options, arguments, command)
@@ -396,6 +427,7 @@ module Nanoc::CLI::Commands
         Nanoc::CLI::Commands::Compile::TimingRecorder,
         Nanoc::CLI::Commands::Compile::GCController,
         Nanoc::CLI::Commands::Compile::FileActionPrinter,
+        Nanoc::CLI::Commands::Compile::StackProfProfiler,
       ]
     end
 
@@ -405,7 +437,7 @@ module Nanoc::CLI::Commands
         .select { |klass| klass.enable_for?(self) }
         .map    { |klass| klass.new(reps: reps) }
 
-      @listeners.each(&:start)
+      @listeners.each(&:start_safely)
     end
 
     def listeners
@@ -420,7 +452,7 @@ module Nanoc::CLI::Commands
     end
 
     def teardown_listeners
-      @listeners.each(&:stop)
+      @listeners.each(&:stop_safely)
     end
 
     def reps
