@@ -9,7 +9,7 @@ EOS
 module Nanoc::CLI::Commands
   class ShowData < ::Nanoc::CLI::CommandRunner
     def run
-      load_site
+      load_site(preprocess: true)
 
       # Get data
       items   = site.items
@@ -40,7 +40,7 @@ module Nanoc::CLI::Commands
     def sorted_reps_with_prev(items)
       prev = nil
       items.sort_by(&:identifier).each do |item|
-        item.reps.sort_by { |r| r.name.to_s }.each do |rep|
+        site.compiler.reps[item].sort_by { |r| r.name.to_s }.each do |rep|
           yield(rep, prev)
           prev = rep
         end
