@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 module Nanoc::Helpers
   # Provides functionality for “capturing” content in one place and reusing
   # this content elsewhere.
@@ -17,7 +15,7 @@ module Nanoc::Helpers
   # @example Capturing content for a summary
   #
   #   <% content_for :summary do %>
-  #     <p>On this item, nanoc is introduced, blah blah.</p>
+  #     <p>On this item, Nanoc is introduced, blah blah.</p>
   #   <% end %>
   #
   # @example Showing captured content in a sidebar
@@ -26,59 +24,29 @@ module Nanoc::Helpers
   #     <h3>Summary</h3>
   #     <%= content_for(@item, :summary) || '(no summary)' %>
   #   </div>
-  #
-  # @example Showing captured content in a sidebar the old, deprecated way (do not use or I will become very angry)
-  #
-  #   <div id="sidebar">
-  #     <h3>Summary</h3>
-  #     <%= @item[:content_for_summary] || '(no summary)' %>
-  #   </div>
   module Capturing
-    # @api private
-    class CapturesStore
-      def initialize
-        @store = {}
-      end
-
-      def []=(item, name, content)
-        @store[item.identifier] ||= {}
-        @store[item.identifier][name] = content
-      end
-
-      def [](item, name)
-        @store[item.identifier] ||= {}
-        @store[item.identifier][name]
-      end
-    end
-
-    class ::Nanoc::Site
-      # @api private
-      def captures_store
-        @captures_store ||= CapturesStore.new
-      end
-
-      # @api private
-      def captures_store_compiled_items
-        require 'set'
-        @captures_store_compiled_items ||= Set.new
-      end
-    end
-
-    # @overload content_for(name, &block)
+    # @overload content_for(name, params = {}, &block)
     #
     #   Captures the content inside the block and stores it so that it can be
     #   referenced later on. The same method, {#content_for}, is used for
     #   getting the captured content as well as setting it. When capturing,
     #   the content of the block itself will not be outputted.
     #
-    #   For backwards compatibility, it is also possible to fetch the captured
-    #   content by getting the contents of the attribute named `content_for_`
-    #   followed by the given name. This way of accessing captures is
-    #   deprecated.
+    #   By default, capturing content with the same name will raise an error if the newly captured
+    #   content differs from the previously captured content. This behavior can be changed by
+    #   providing a different `:existing` option to this method:
+    #
+    #   * `:error`: When content already exists and is not identical, raise an error.
+    #
+    #   * `:overwrite`: Overwrite the previously captured content with the newly captured content.
+    #
+    #   * `:append`: Append the newly captured content to the previously captured content.
     #
     #   @param [Symbol, String] name The base name of the attribute into which
     #     the content should be stored
     #
+    #   @option params [Symbol] existing Can be either `:error`, `:overwrite`, or `:append`
+    #
     #   @return [void]
     #
     # @overload content_for(item, name)
@@ -86,7 +54,7 @@ module Nanoc::Helpers
     #   Fetches the capture with the given name from the given item and
     #   returns it.
     #
-    #   @param [Nanoc::Item] item The item for which to get the capture
+    #   @param [Nanoc::Int::Item] item The item for which to get the capture
     #
     #   @param [Symbol, String] name The name of the capture to fetch
     #
@@ -94,17 +62,46 @@ module Nanoc::Helpers
     def content_for(*args, &block)
       if block_given? # Set content
         # Get args
-        if args.size != 1
-          raise ArgumentError, 'expected 1 argument (the name ' \
-            "of the capture) but got #{args.size} instead"
+        case args.size
+        when 1
+          name = args[0]
+          params = {}
+        when 2
+          name = args[0]
+          params = args[1]
+        else
+          raise ArgumentError, 'expected 1 or 2 argument (the name ' \
+            "of the capture, and optionally params) but got #{args.size} instead"
         end
         name = args[0]
+        existing_behavior = params.fetch(:existing, :error)
 
-        # Capture and store
+        # Capture
         content = capture(&block)
-        @site.captures_store[@item, name.to_sym] = content
+
+        # Prepare for store
+        snapshot_contents = @item.reps[:default].unwrap.snapshot_contents
+        capture_name = "__capture_#{name}".to_sym
+        case existing_behavior
+        when :overwrite
+          snapshot_contents[capture_name] = ''
+        when :append
+          snapshot_contents[capture_name] ||= ''
+        when :error
+          if snapshot_contents[capture_name] && snapshot_contents[capture_name] != content
+            # FIXME: get proper exception
+            raise "a capture named #{name.inspect} for #{@item.identifier} already exists"
+          else
+            snapshot_contents[capture_name] = ''
+          end
+        else
+          raise ArgumentError, 'expected :existing_behavior param to #content_for to be one of ' \
+            ":overwrite, :append, or :error, but #{existing_behavior.inspect} was given"
+        end
+
+        # Store
+        snapshot_contents[capture_name] << content
       else # Get content
-        # Get args
         if args.size != 2
           raise ArgumentError, 'expected 2 arguments (the item ' \
             "and the name of the capture) but got #{args.size} instead"
@@ -112,29 +109,19 @@ module Nanoc::Helpers
         item = args[0]
         name = args[1]
 
-        # Create dependency
-        current_item = @site.compiler.dependency_tracker.top
-        if item != current_item
-          Nanoc::NotificationCenter.post(:visit_started, item)
-          Nanoc::NotificationCenter.post(:visit_ended,   item)
+        rep = item.reps[:default].unwrap
 
-          # This is an extremely ugly hack to get the compiler to recompile the
-          # item from which we use content. For this, we need to manually edit
-          # the content attribute to reset it. :(
-          # FIXME: clean this up
-          unless @site.captures_store_compiled_items.include? item
-            @site.captures_store_compiled_items << item
-            item.forced_outdated = true
-            item.reps.each do |r|
-              raw_content = item.raw_content
-              r.content = { raw: raw_content, last: raw_content }
-              raise Nanoc::Errors::UnmetDependency.new(r)
-            end
+        # Create dependency
+        if @item.nil? || item != @item.unwrap
+          dependency_tracker = @config._context.dependency_tracker
+          dependency_tracker.bounce(item.unwrap)
+
+          unless rep.compiled?
+            raise Nanoc::Int::Errors::UnmetDependency.new(rep)
           end
         end
 
-        # Get content
-        @site.captures_store[item, name.to_sym]
+        rep.snapshot_contents["__capture_#{name}".to_sym]
       end
     end
 
@@ -148,7 +135,7 @@ module Nanoc::Helpers
       erbout_length = erbout.length
 
       # Execute block
-      block.call
+      yield
 
       # Get new piece of erbout
       erbout_addition = erbout[erbout_length..-1]
